"use client";

import * as React from "react";

import { motion } from "framer-motion";

import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

import { ImageBaseUrl } from "@/configs/api";
import useEmblaCarousel from "embla-carousel-react";
import { useLocale } from "next-intl";
import { CategoryItem } from "./category-item";



export function CategorySwiper({ categories }: { categories: any[] }) {
	const locale = useLocale() as Locale;
	const [emblaRef, emblaApi] = useEmblaCarousel({
		loop: false,
		direction: "rtl",
		align: "start",
		slidesToScroll: 1,
		skipSnaps: false
	});


	const isRTL = locale === "ar";
	const [groupedItems, setGroupedItems] = React.useState<any>([]);
	const [currentSlide, setCurrentSlide] = React.useState(0);
	const [totalSlides, setTotalSlides] = React.useState(0);

	const ITEMS_PER_PAGE = 8;

	const chunkArray = (array: any[] = [], size: number): any[][] => {
		return array.reduce((chunks, item, index) => {
			const chunkIndex = Math.floor(index / size);
			if (!chunks[chunkIndex]) {
				chunks[chunkIndex] = [];
			}
			chunks[chunkIndex].push(item);
			return chunks;
		}, [] as any[][]);
	};

	React.useEffect(() => {
		if (!categories?.length) {
			setGroupedItems([]);
			return;
		}

		try {
			const groups = chunkArray(categories, ITEMS_PER_PAGE);
			setGroupedItems(groups);
			// console.log(`Created ${groups.length} groups of ${ITEMS_PER_PAGE} items each`);
		} catch (error) {
			console.error("Error grouping categories:", error);
			setGroupedItems([]);
		}
	}, [categories]);


	React.useEffect(() => {
		if (emblaApi) {
			// Update total slides count
			const slides = emblaApi.scrollSnapList().length;
			setTotalSlides(slides);
			// console.log("Total slides:", slides);

			// Add scroll listener
			const onSelect = () => {
				setCurrentSlide(emblaApi.selectedScrollSnap());
				// console.log("Current slide index:", emblaApi.selectedScrollSnap());
			};

			emblaApi.on("select", onSelect);
			onSelect(); // Initialize current slide

			return () => {
				emblaApi.off("select", onSelect);
			};
		}
	}, [emblaApi, groupedItems]);

	const scrollPrev = React.useCallback(() => {
		if (emblaApi) {
			emblaApi.scrollPrev();
			// console.log("Scrolling to previous slide");
		}
	}, [emblaApi]);

	const scrollNext = React.useCallback(() => {
		if (emblaApi) {
			// console.log("Attempting to scroll next");
			// console.log("Current slide before:", emblaApi.selectedScrollSnap());
			emblaApi.scrollNext();
			// console.log("Current slide after:", emblaApi.selectedScrollSnap());
		} else {
			// console.log("emblaApi is not initialized");
		}
	}, [emblaApi]);


	const containerVariants = {
		hidden: { opacity: 0 },
		visible: {
			opacity: 1,
			transition: { duration: 0.5, staggerChildren: 0.1 },
		},
	};

	// console.log("groupedItems: ", groupedItems);
	return (
		groupedItems?.length > 0 &&
		<motion.div className="relative"
			initial="hidden"
			animate="visible"
			variants={containerVariants}>

			<motion.div className="embla__viewport overflow-hidden" ref={emblaRef}>
				<div className="embla__container flex">
					{groupedItems?.map((group: any, index: any) => (
						<div className="embla__slide flex-[0_0_100%] min-w-0" key={index}>
							<div className="grid grid-cols-4 gap-4">
								{group?.map((category: any) => (
									<Link href={`/shop?category_id=${category?.id}` as any} key={category?.id}>
										<CategoryItem
											key={category?.id}
											icon={ImageBaseUrl + category?.image}
											title={locale == "ar" ? category?.name_ar : category?.name_en}
											count={category?.category_products?.length}
											isMain={false}
											locale={locale}
											animate
											index={index}
										/>
									</Link>
								))}
							</div>
						</div>
					))}
				</div>
			</motion.div>

			{/* Navigation buttons */}
			{groupedItems?.length > 1 && (
				<motion.div
					className="mt-8 flex items-center justify-center gap-4"
					initial={{ opacity: 0, y: 20 }}
					animate={{ opacity: 1, y: 0 }}
					transition={{ delay: 0.5 }}
				>
					<AnimatedButton
						onClick={scrollPrev}
						isRTL={isRTL}
						direction="prev"
						disabled={currentSlide === 0}

					/>
					<div className="flex gap-2">
						{Array.from({ length: totalSlides })?.map((_, index) => (
							<AnimatedDot
								key={index}
								isActive={currentSlide === index}
								onClick={() => emblaApi?.scrollTo(index)}
							/>
						))}
					</div>
					<AnimatedButton
						onClick={scrollNext}
						isRTL={isRTL}
						direction="next"
						disabled={currentSlide === totalSlides - 1}
					/>
				</motion.div>
			)}
		</motion.div>
	);
}

interface AnimatedButtonProps {
	onClick: () => void;
	isRTL: boolean;
	direction: "prev" | "next";
	disabled: boolean;
}

const AnimatedButton: React.FC<AnimatedButtonProps> = ({
	onClick,
	isRTL,
	direction,
	disabled
}) => {
	return (
		<motion.button
			onClick={onClick}
			className={cn("flex h-8 w-8 items-center justify-center rounded-full border border-[#2895C8] bg-[#2895C8] text-white",
				!disabled && "hover:bg-[#2895C8]/90"
			)}
			whileTap={{ scale: 0.9 }}
			whileHover={{
				boxShadow: !disabled ? "0px 0px 8px rgba(40, 149, 200, 0.6)" : ""
			}}
			disabled={disabled}
			style={{ cursor: disabled ? "default" : "pointer" }}
		>
			<motion.svg
				width="11"
				height="6"
				viewBox="0 0 11 6"
				fill="none"
				xmlns="http://www.w3.org/2000/svg"
				className={cn({
					"rotate-180":
						(direction === "next" && !isRTL) || (direction === "prev" && isRTL),
				})}
				initial={{ pathLength: 0, opacity: 0 }}
				animate={{ pathLength: 1, opacity: 1 }}
				transition={{ duration: 0.5 }}
			>
				<motion.path
					d="M0.241141 2.64645C0.0458641 2.84171 0.0458641 3.15829 0.241141 3.35355L2.73886 5.85125C2.93413 6.04652 3.25072 6.04652 3.44598 5.85125C3.64124 5.65599 3.64124 5.33941 3.44598 5.14415L1.30183 3L3.44598 0.855847C3.64124 0.660585 3.64124 0.344002 3.44598 0.148741C3.25072 -0.0465202 2.93413 -0.0465202 2.73886 0.148741L0.241141 2.64645ZM10.5 2.5L0.594748 2.5V3.5L10.5 3.5V2.5Z"
					fill="currentColor"
				/>
			</motion.svg>
		</motion.button>
	);
};

interface AnimatedDotProps {
	isActive: boolean;
	onClick: () => void;
}

const AnimatedDot: React.FC<AnimatedDotProps> = ({ isActive, onClick }) => {
	return (
		<motion.button
			className={cn(
				"h-2 w-2 rounded-full bg-[#2895C8]",
				isActive ? "border-2 border-[#2895C8] opacity-100" : "opacity-30"
			)}
			onClick={onClick}
			whileHover={{ scale: 1.2 }}
			whileTap={{ scale: 0.8 }}
			animate={
				isActive
					? {
						scale: [1, 1.2, 1],
						transition: {
							duration: 0.5,
							repeat: Infinity,
							repeatType: "reverse",
						},
					}
					: undefined
			}
		/>
	);
};
